/* gxTar - Gnomified Archive Frontend
 * Copyright (C) 1998 Chris Rogers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option) 
 * any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */



#ifdef GNOME
#include <config.h> 
#include <gnome.h>
#include "menu_gnome.h"
#include "toolbar_gnome.h"
#include "gnomestuff.h"
#else
#include <gtk/gtk.h>
#include "menu_gtk.h"
#include "toolbar_gtk.h"
#endif

#include "archive.h"
#include "filelist.h"
#include "statusbar.h"



/*our general clean up and exit routine*/
void delete_event (GtkWidget *widget, gpointer *data) {
  quitArchive();
  gtk_main_quit();
  return;
}


void prepare_app();


/*Create the widgets and go*/
int main (int argc, char *argv[]) {
  
   
#ifdef GNOME
  
  GnomeClient *client;
  
  argp_program_version = VERSION;
  
  /* Initialize the i18n stuff */
  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
  textdomain (PACKAGE);
  
  gnome_init ("gxtar", &parser, argc, argv, 0, NULL);
  
  client= gnome_master_client ();
  
  /* Arrange to be told when something interesting happens.  */
  gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
                      GTK_SIGNAL_FUNC (save_state), (gpointer) argv[0]);
  gtk_signal_connect (GTK_OBJECT (client), "die",
                      GTK_SIGNAL_FUNC (die), NULL);
  
  if (GNOME_CLIENT_CONNECTED (client))
    {
      
      GnomeClient *cloned= gnome_cloned_client ();
      
      if (cloned)
        {
          /* If cloned is non NULL, we have been restarted.  */
          restarted= 1;
          gnome_config_push_prefix (gnome_client_get_config_prefix (cloned));
          os_x = gnome_config_get_int ("Geometry/x");
          os_y = gnome_config_get_int ("Geometry/y");
          os_w = gnome_config_get_int ("Geometry/w");
          os_h = gnome_config_get_int ("Geometry/h");
          gnome_config_pop_prefix ();
        }
    }
  
  if (! just_exit)
    {
      prepare_app();
      gtk_main();
    }
 
#else

  /* Initialize GTK */
  gtk_init (&argc, &argv);
  prepare_app();
  gtk_main();

#endif
 
 return 0;
}

void prepare_app() {

  /* create a new window */

  GtkWidget *frame;
  GtkWidget *fTop;
  GtkWidget *fBottom;


#ifdef GNOME
  
  window = gnome_app_new ("gxtar", _("gxTar - Unknown") );
  
  if (restarted) {
    gtk_widget_set_uposition (window, os_x, os_y);
    gtk_widget_set_usize     (window, os_w, os_h);
  }

#else

  window = gtk_window_new (GTK_WINDOW_TOPLEVEL); 
  gtk_window_set_title (GTK_WINDOW (window), "gxTar - Unknown");
  gtk_widget_set_name (window, "gxTar");

#endif

  gtk_widget_realize (window);
  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
		      GTK_SIGNAL_FUNC (delete_event), NULL);
  gtk_widget_set_usize (window, 400, 400);
  gtk_widget_set_uposition (window, 20, 20);
  gtk_container_border_width (GTK_CONTAINER (window), 1 );
      
  /*create the containers*/
  frame = gtk_vbox_new(FALSE, 0);
  fTop = gtk_hbox_new(FALSE, 0);
  fBottom = gtk_hbox_new(FALSE, 0);
  
 
  gtk_container_border_width(GTK_CONTAINER( frame), 1);
  
#ifdef GNOME
  gnome_app_set_contents ( GNOME_APP (window), frame);
  createMenu(window);
  createToolbar(window);
#else
  gtk_container_add (GTK_CONTAINER (window), frame);
  createMenu(frame);
  gtk_container_border_width(GTK_CONTAINER( fTop ), 2);
  gtk_box_pack_start(GTK_BOX(frame), fTop, FALSE, FALSE, 0);
  createToolbar(fTop);
  gtk_widget_show(fTop);
#endif

   
  gtk_container_border_width(GTK_CONTAINER( fBottom), 7);
  gtk_box_pack_start(GTK_BOX(frame), fBottom, TRUE, TRUE, 0);
  createFileList(fBottom);
  createStatusbar(frame);

  /*show it all*/
 
  gtk_widget_show(fBottom);
  gtk_widget_show(frame);
  gtk_widget_show(window);

}



